Function diem_infallible::duration_since_epoch [−][src]
pub fn duration_since_epoch() -> DurationExpand description
Gives the duration since the Unix epoch, notice the expect.
pub fn duration_since_epoch() -> DurationGives the duration since the Unix epoch, notice the expect.